#include <pic16f886.h>
#include <xc.h>
#include "hitec_c_i2c.h"
#include "user_define.h"

/*------------------------IC2---------------------*/
void I2CInit(void){
        TRISC3 = 1;      /* SDA and SCL as input pin */
		NOP();
        TRISC4 = 1;      /* these pins can be configured either i/p or o/p */
		NOP();
        SSPSTAT |= 0x80; /* Slew rate disabled */
        SSPCON = 0x28;   /* SSPEN = 1, I2C Master mode, clock = FOSC/(4 * (SSPADD + 1)) */
        SSPADD = 0x28;    /* 100Khz @ 4Mhz Fosc */
}

void I2CStart(){
        SEN = 1;         /* Start condition enabled */
		NOP();
        while(SEN);      /* automatically cleared by hardware */
                     /* wait for start condition to finish */
}

void I2CStop(){
        PEN = 1;         /* Stop condition enabled */
		NOP();
        while(PEN);      /* Wait for stop condition to finish */
                     /* PEN automatically cleared by hardware */
}

void I2CRestart(){
        RSEN = 1;        /* Repeated start enabled */
		NOP();
        while(RSEN);     /* wait for condition to finish */
}

void I2CAck(){
        ACKDT = 0;       /* Acknowledge data bit, 0 = ACK */
		NOP();
        ACKEN = 1;       /* Ack data enabled */
		NOP();
        while(ACKEN);    /* wait for ack data to send on bus */
}

void I2CNak(){
        ACKDT = 1;       /* Acknowledge data bit, 1 = NAK */
		NOP();
        ACKEN = 1;       /* Ack data enabled */
		NOP();
        while(ACKEN);    /* wait for ack data to send on bus */
}

void I2CWait(){
        while ( ( SSPCON2 & 0x1F ) || ( SSPSTAT & 0x04 ) );
    /* wait for any pending transfer */
}

void I2CSend(unsigned char dat){
        SSPBUF = dat;    /* Move data to SSPBUF */
        while(BF);       /* wait till complete data is sent from buffer */
        I2CWait();       /* wait for any pending transfer */
}

unsigned char I2CRead(void){
        unsigned char temp;
/* Reception works if transfer is initiated in read mode */
        RCEN = 1;        /* Enable data reception */
        while(!BF);      /* wait for buffer full */
        temp = SSPBUF;   /* Read serial buffer and store in temp register */
        I2CWait();       /* wait to check any pending transfer */
        return temp;     /* Return the read data from bus */
}

void	i2c_ns73m_write(unsigned char add,unsigned char data)
{
	I2CStart();
	I2CSend(NS73M_ADR);
	I2CSend(add);
	I2CSend(data);
	I2CStop();
}
